package VMOMI::AgentInstallFailedReason;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
